@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from pyramid.security import Allow, Authenticated
+from pyramid.authorization import Allow, Authenticated
 
 DEFAULT_PERM = [(Allow, Authenticated, "oauth"), ]
 
