@@ -105,7 +105,7 @@ def handle_authcode(
     parts = urlparse(redirection_uri.uri)
     qparams = dict(parse_qsl(parts.query))
 
-    user_login = request.authenticated_userid()
+    user_login = request.authenticated_userid
     user_id = Login.query().filter_by(login=user_login).first().user_id
     auth_code = OidcCode(client, user_id, redirection_uri.uri, scopes)
     if nonce is not None:
@@ -198,7 +198,7 @@ def authorize_view(request):
 
     http://openid.net/specs/openid-connect-core-1_0.html#AuthRequest
     """
-    logger.debug(u"Authorize view")
+    logger.debug("Authorize view")
     client_id = request.params.get('client_id')
     try:
         client = validate_client(client_id)
