@@ -112,7 +112,7 @@ def login_view(request):
             logger.exception(e.cstruct)
             return dict(form=e.render())
 
-        logger.debug(u" + '{0}' has been authenticated".format(
+        logger.debug(" + '{0}' has been authenticated".format(
             form_datas['login'])
         )
         connect_user(request, form_datas)
